@@ -23,6 +23,7 @@ DEFAULT_URANIUM_FILE = "uranium.yaml"
 
 
 def main(argv=sys.argv[1:]):
+    _activate_virtualenv(os.curdir)
     options = docopt(__doc__,  argv=argv)
     uranium_file = options['<uranium_file>'] or DEFAULT_URANIUM_FILE
     uranium = _get_uranium(uranium_file)
@@ -33,3 +34,11 @@ def _get_uranium(uranium_file):
     root = os.path.abspath(os.curdir)
     config = load_config_from_file(uranium_file)
     return Uranium(config, root)
+
+
+def _activate_virtualenv(uranium_dir):
+    """ this will activate a virtualenv in the case one exists """
+    activate_this_path = os.path.join(uranium_dir, 'bin', 'activate_this.py')
+    with open(activate_this_path) as fh:
+        code = compile(fh.read(), activate_this_path, 'exec')
+        exec(code, {}, {})
